#
# spec file for package hashlink
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hashlink
Version:        1.14
Release:        1.3
Summary:        A virtual machine for Haxe
License:        MIT
URL:            https://hashlink.haxe.org/
Source0:        https://github.com/HaxeFoundation/%{name}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch01:        0001-cmake-Install-hlc_main.c-with-hl.h-and-hlc.h.patch
# PATCH-FIX-UPSTREAM
Patch02:        0001-Disable-the-JIT-tests-on-arm-architectures.patch
# PATCH-FIX-UPSTREAM
Patch03:        0001-cmake-Don-t-build-the-interpreter-on-ARM.patch
# PATCH-FIX-UPSTREAM
Patch04:        0001-cmake-Don-t-run-the-version-test-if-the-interpreter-.patch
# PATCH-FIX-OPENSUSE
Patch05:        0001-fix-rpath.patch
BuildRequires:  cmake
BuildRequires:  haxe >= 4.0
BuildRequires:  mbedtls-devel < 3
BuildRequires:  cmake(sdl2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libturbojpeg)
BuildRequires:  pkgconfig(libuv)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(vorbis)
Requires:       %{name}-hdlls = %{version}
Enhances:       haxe

%description
HashLink is a virtual machine for Haxe.
Haxe supports two modes of compilation for HashLink:
* Compilation to HashLink bytecode. This mode has a very fast compilation time,
  so it is suitable for daily development.
* Compilation to HashLink/C code, compiled with a native compiler to a regular
  executable. This mode results in the best performance, so it is suitable for
  final releases.

%package -n libhl1
Summary:        HashLink library

%description -n libhl1
This subpackage provides the libhl library for HashLink.

%package hdlls
Summary:        Hdll libraries for HashLink

%description hdlls
This subpackage provides the hdll libraries for HashLink.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}-hdlls  = %{version}
Requires:       libhl1  = %{version}

%description devel
Contains the files required to compile to a native executable the HashLink/C
code generated by the haxe compiler.

%prep
%autosetup -n hashlink-%{version} -p1

%build
# The build process for the tests uses haxe and requires the hashlink library
haxelib setup ./haxelib
haxelib dev hashlink other/haxelib
%cmake
%cmake_build

%install
%cmake_install

%check
# uvsample.hl fails when run in parallel
%ctest "-j0"

%post   -n libhl1 -p /sbin/ldconfig
%postun -n libhl1 -p /sbin/ldconfig

%files
%ifnarch %{arm} %{arm64}
%{_bindir}/hl
%endif
%license LICENSE
%doc README.md

%files -n libhl1
%license LICENSE
%{_libdir}/*.so.1*

%files hdlls
%license LICENSE
%{_libdir}/*.hdll

%files devel
%license LICENSE
%{_libdir}/*.so
%{_includedir}/*.h
%{_includedir}/hlc_main.c

%changelog
* Thu Jan 11 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 1.14
  * improved very significantly GC performances by using prefetch and multiple
    mark threads
  * reimplement CArray using native opcodes (requires Haxe 4.4+)
  * dynobj fields are now correctly ordered in the order they were set
  * added Prefetch and Asm opcodes (requires Haxe 4.4+)
  * added Intel VTune support (JIT only)
  * upgraded to PCRE2 for regular expressions
  * ... and many additional changes and fixes
- Drop 0001-fix-return-non-void-functions.patch
* Tue Feb  7 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 1.13
  * support for CArray (contiguous memory array of objects)
  * support for @:packed (requires latest Haxe) : declare an object field like
    in C struct
  * improved GC performances
  * completed int64 support, including int64 maps
  * added DirectX12 support
  * added SDL/DX mouse handle API (by @Yanrishatum)
  * added named threads support + debugger support
  * ... and many additional changes
- Add 0001-fix-return-non-void-functions.patch: fix build with -Werror=return-type
- Drop 0001-cmake-Link-sdl.hdll-with-OpenGL.patch: accepted upstream
* Sun Jul 10 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add 0001-fix-rpath.patch: Fix the RPATH of the hl binary to comply with rpm validations
* Sat May 21 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add 0001-cmake-Don-t-build-the-interpreter-on-ARM.patch and
  0001-cmake-Don-t-run-the-version-test-if-the-interpreter-.patch : disable the
  interpreter on ARM architectures
* Thu May  5 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to version 1.12
  * support for hot reload
  * added native int64 support (for x64 only, compile with -D hl-legacy32 to keep hl32 i64 emulation)
  * added field name to null access exceptions
  * added hl.Api.compact to compact a set of values into a single GC block
  * better stack primitives for faster haxe throw
  * added 16 bits PNG decoding (fmt)
  * added captured stack for closures (when debugger connected)
  * added ftell2/fseek2 for large file support
  * added optional library support @:native("?lib","name") static function foo() : Void allowing runtime detection of libraries (as well as hl.Api.isPrimLoaded)
  * changed Windows binary to use VS2015 (was VS2013)
* Sat Apr 30 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Move the libraries to subpackages and don't reference the devel subpackage from the main package
- Include the license in the devel subpackage
* Mon Feb 28 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- 0001-Disable-the-JIT-tests-on-arm-architectures.patch : Add reference to pull request
* Fri Feb 25 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add 0001-Disable-the-JIT-tests-on-arm-architectures.patch to disable JIT tests on ARM
* Sat Feb 19 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Use cmake to build the project
- Add 0001-cmake-Link-sdl.hdll-with-OpenGL.patch to fix linking with OpenGL
- Add 0001-cmake-Install-hlc_main.c-with-hl.h-and-hlc.h.patch to install hlc_main.c
* Fri Feb 18 2022 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Initial version
